@@ -38,7 +38,7 @@ function(object, top.n.skill.classes = 6, overwrite = FALSE, ...){
 
 	IDI <- t(matrix(round(object$IDI, 4)))
 	rownames(IDI) <- ""
-	colnames(IDI) <- rownames(object$coef)
+	colnames(IDI) <- rownames(object$item)
 	# item parameters
 	item <- data.frame( "item" = colnames(object$data) , "guess" = object$guess[,1] , 
 				"slip" = object$slip[,1] , "IDI" = object$IDI , "rmsea" = object$itemfit.rmsea )
